@@ -31,5 +31,6 @@ ENCMAP = {
 }
 
 
-add_map("bacon", ENCMAP, ignore_case="both", pattern=r"bacon(?:(?:ian)?[-_]cipher)?([\-_].{2})?$", printables_rate=1.)
+add_map("bacon", ENCMAP, ignore_case="both", pattern=r"bacon(?:(?:ian)?[-_]cipher)?([\-_].{2})?$", expansion_factor=5.,
+        printables_rate=1.)
 
