@@ -23,20 +23,26 @@ __examples2__ = {
     'enc(prot1|prog-caesar_1)':    {'this is a test': "ujlw oz j eqfh"},
     'enc(prot3|pcaesar-3)':        {'this is a test': "wlny qb l gshj"},
 }
+__examples3__ = {
+    'enc(arot0|arot--10|arot100)': None,
+    'enc(arot1|alt-caesar_1)':     {'this is a test': "ugjr ht b udts"},
+    'enc(arot3|acaesar-3)':        {'this is a test': "welp fv d wbvq"},
+}
 __guess1__ = ["rot-%d" % i for i in range(1, 26)] + ["rot-47"]
 __guess2__ = ["progressive-rot-%d" % i for i in range(1, 26)] + ["progressive-rot-n%d" % i for i in range(1, 26)]
+__guess3__ = ["alternative-rot-%d" % i for i in range(1, 26)]
 
 
 ROT47 = "!\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~"
 
 
-def _rotn(text, n=13, a=(LC, UC, DIG), prog=False, neg=False):
+def _rotn(text, n=13, a=(LC, UC), alt=False, prog=False, neg=False):
     r = ""
     for i, c in enumerate(ensure_str(text)):
         found = False
         for l in a:
             if c in l:
-                r += l[(l.index(c) + n + ([1, -1][neg] * i if prog else 0)) % len(l)]
+                r += l[(l.index(c) + [1, -1][alt and i % 2 == 1] * n + ([1, -1][neg] * i if prog else 0)) % len(l)]
                 found = True
                 break
         if not found:
@@ -44,6 +50,18 @@ def _rotn(text, n=13, a=(LC, UC, DIG), prog=False, neg=False):
     return r
 
 
+def arot_encode(i):
+    def encode(text, errors="strict"):
+        return _rotn(ensure_str(text), i, alt=True), len(text)
+    return encode
+
+
+def arot_decode(i):
+    def decode(text, errors="strict"):
+        return _rotn(ensure_str(text), -i, alt=True), len(text)
+    return decode
+
+
 def rot_encode(i):
     def encode(text, errors="strict"):
         t = ensure_str(text)
@@ -72,8 +90,12 @@ def prot_decode(n, i):
     return decode
 
 
-add("rot", rot_encode, rot_decode, r"(?:caesar|rot)[-_]?([1-9]|1[0-9]|2[0-5]|47)$", aliases=["caesar"],
-    entropy=lambda e: e, printables_rate=lambda pr: pr, examples=__examples1__, guess=__guess1__)
+add("alternative-rot", arot_encode, arot_decode, r"a(?:lt(?:ernative)?-)?(?:caesar|rot)[-_]?([1-9]|1[0-9]|2[0-5])$",
+    penalty=.2, entropy=lambda e: e, printables_rate=lambda pr: pr, transitive=True, examples=__examples3__,
+    guess=__guess3__)
+add("rot", rot_encode, rot_decode, r"(?:caesar|rot)[-_]?([1-9]|1[0-9]|2[0-5]|47)$", aliases=["caesar"], penalty=.2,
+    entropy=lambda e: e, printables_rate=lambda pr: pr, transitive=True, examples=__examples1__, guess=__guess1__)
 add("progressive-rot", prot_encode, prot_decode, r"p(?:rog(?:ressive)?-)?(?:caesar|rot)[-_]?(n?)([1-9]|1[0-9]|2[0-5])$",
-    entropy=lambda e: e, printables_rate=lambda pr: pr, examples=__examples2__, guess=__guess2__)
+    penalty=.2, entropy=lambda e: e, printables_rate=lambda pr: pr, transitive=True, examples=__examples2__,
+    guess=__guess2__)
 
